@@ -2,8 +2,16 @@
 
 # Fake the system time
 
-dat="$1"
 
+dat="$1"
+static=0
+
+
+if [ "$dat" = "-s" -o "$dat" = "--static" ] ; then
+	static=1
+	shift
+	dat="$1"
+fi
 if [ "$dat" = "-v" -o "$dat" = "--version" ] ; then
 	echo "$0: Version @VERSION@"
 	echo ""
@@ -11,7 +19,7 @@ if [ "$dat" = "-v" -o "$dat" = "--version" ] ; then
 	exit 0
 fi
 if [ -z "$dat" -o "$dat" = "-h" -o "$dat" = "-?" -o "$dat" = "--help" ] ; then
-	echo "Usage: $0 date program args..."
+	echo "Usage: $0 [-s|--static] date program args..."
 	echo ""
 	echo "Run 'program' with 'args'."
 	echo "The program will believe that the current time is 'date'."
@@ -21,13 +29,19 @@ fi
 shift
 
 # Assume that 'date' already printed an error message
-sec=$(date -d "$dat" '+%s')
+sec1=$(date -d "$dat" '+%s')
 if [ $? -ne 0 ] ; then exit 1 ; fi
 
-sec=$(expr $(date '+%s') - $sec)
+sec2=$(expr $(date '+%s') - $sec1)
 if [ $? -ne 0 ] ; then exit 1 ; fi
 
 export LD_PRELOAD="${LD_PRELOAD}${LD_PRELOAD:+:}/usr/lib/datefudge/datefudge.so"
-export DATEFUDGE=$sec
+if [ "$static" = "1" ]; then
+	export DATEFUDGE=$sec1
+	export DATEFUDGE_DOSTATIC="1"
+else
+	export DATEFUDGE=$sec2
+	unset  DATEFUDGE_DOSTATIC
+fi
 
 exec "$@"
